var annotated =
[
    [ "CGAL", null, [
      [ "Is_convex_2", "classCGAL_1_1Is__convex__2.html", "classCGAL_1_1Is__convex__2" ],
      [ "Is_vacuously_valid", "classCGAL_1_1Is__vacuously__valid.html", "classCGAL_1_1Is__vacuously__valid" ],
      [ "Is_y_monotone_2", "classCGAL_1_1Is__y__monotone__2.html", "classCGAL_1_1Is__y__monotone__2" ],
      [ "Partition_is_valid_traits_2", "classCGAL_1_1Partition__is__valid__traits__2.html", "classCGAL_1_1Partition__is__valid__traits__2" ],
      [ "Partition_traits_2", "classCGAL_1_1Partition__traits__2.html", "classCGAL_1_1Partition__traits__2" ]
    ] ],
    [ "ConvexPartitionIsValidTraits_2", "classConvexPartitionIsValidTraits__2.html", "classConvexPartitionIsValidTraits__2" ],
    [ "IsYMonotoneTraits_2", "classIsYMonotoneTraits__2.html", "classIsYMonotoneTraits__2" ],
    [ "OptimalConvexPartitionTraits_2", "classOptimalConvexPartitionTraits__2.html", "classOptimalConvexPartitionTraits__2" ],
    [ "PartitionIsValidTraits_2", "classPartitionIsValidTraits__2.html", "classPartitionIsValidTraits__2" ],
    [ "PartitionTraits_2", "classPartitionTraits__2.html", "classPartitionTraits__2" ],
    [ "PolygonIsValid", "classPolygonIsValid.html", "classPolygonIsValid" ],
    [ "YMonotonePartitionIsValidTraits_2", "classYMonotonePartitionIsValidTraits__2.html", "classYMonotonePartitionIsValidTraits__2" ]
];